pub struct RelayPool { /* private fields */ }Implementations
Sourceimpl RelayPool
impl RelayPool
Sourcepub fn shuffled_urls(&self) -> Vec<String>
pub fn shuffled_urls(&self) -> Vec<String>
Shuffle in place, sort failed to back, return all URLs.
Sourcepub fn shuffled_urls_n(&self, n: usize) -> Vec<String>
pub fn shuffled_urls_n(&self, n: usize) -> Vec<String>
Shuffle in place, sort failed to back, return up to n URLs.
pub fn mark_failed(&self, url: &str)
pub fn mark_alive(&self, url: &str)
Sourcepub fn refresh(&self, new_urls: impl IntoIterator<Item = String>)
pub fn refresh(&self, new_urls: impl IntoIterator<Item = String>)
Add new URLs to the pool.
pub fn is_empty(&self) -> bool
pub fn urls(&self) -> Vec<String>